#region Copyright Syncfusion Inc. 2001 - 2007
//
//  Copyright Syncfusion Inc. 2001 - 2007. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

using System;
using System.ComponentModel;
using System.Windows.Forms;
using Syncfusion.XlsIO;
using System.Globalization;
using System.IO;
using Syncfusion.ExcelToPdfConverter;
using Syncfusion.Pdf;
using ReportFromTemplate;
using System.Collections.Generic;
using System.Linq;

namespace EssentialXlsIOSamples
{
  /// <summary>
  /// Summary description for Form1.
  /// </summary>
  public class CreateSpreadsheet : Form
  {
    #region Constants
    //private const string DEFAULTPATH = @"..\..\..\..\..\..\..\..\Common\Data\{0}";

    private const string DEFAULTPATH = @"..\..\Data\{0}";
    private const string OUTPUTPATH = @"..\..\Output\{0}";
    #endregion

    #region Fields
    private System.Windows.Forms.Button btnCreate;
    private Label label2;
    private PictureBox pictureBox3;

    /// <summary>
    /// Required designer variable.
    /// </summary>
    private System.ComponentModel.Container components = null;
    #endregion

    #region Initialize
    public CreateSpreadsheet()
    {
      //
      // Required for Windows Form Designer support
      //
      InitializeComponent();
      this.FormBorderStyle = FormBorderStyle.FixedSingle;
      this.StartPosition = FormStartPosition.CenterScreen;
      //
      // TODO: Add any constructor code after InitializeComponent call
      //
    }
    #endregion

    #region CreateSpreadsheet
    private void btnCreate_Click(object sender, System.EventArgs e)
    {
      #region Workbook Intialization
      //New instance of XlsIO is created.[Equivalent to launching MS Excel with no workbooks open].
      //The instantiation process consists of two steps.

      //Step 1 : Instantiate the spreadsheet creation engine.
      ExcelEngine excelEngine = new ExcelEngine();

      //The workbook is Created.
      IWorkbook workbook = null;

      var documentsPath = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "Reports");
      var path = Path.Combine(documentsPath, "StartupList.xlsx");
      workbook = excelEngine.Excel.Workbooks.Open(path);

      if (workbook == null) return;
      //The first worksheet object in the worksheets collection is accessed.
      var worksheet1 = workbook.Worksheets[0];

      //Create Template Marker Processor
      var marker = workbook.CreateTemplateMarkersProcessor();
      var sl = new StartupList();
      sl.PlantDescription = "This is the description";
      marker.AddVariable("StartupList", sl);
      var item = new StartupListItem();
      item.Remark = "This is a long line that should be shown in its entirety but it gets truncated when converted to PDF.";
      var items = new List<StartupListItem>();
      items.Add(item);
      marker.AddVariable("StartupListItems", items);
      marker.AddVariable("Customer", "");
      marker.AddVariable("WorkingOrder", "");
      marker.AddVariable("StartupListSignature", "");
      marker.ApplyMarkers();
      for (var i = 4; i < worksheet1.Rows.Count(); i++)
      {
        worksheet1.AutofitRow(i + 1);
        if (i + 1 >= 5)
        {
          int oddEven = (i + 1) % 2;
          if (oddEven == 0)
          {
            worksheet1.Range["A" + (i + 1).ToString() + ":K" + (i + 1).ToString()].CellStyle.ColorIndex = ExcelKnownColors.White;
          }
          else
          {
            worksheet1.Range["A" + (i + 1).ToString() + ":K" + (i + 1).ToString()].CellStyle.ColorIndex = ExcelKnownColors.Grey_25_percent;
          }
        }
      }

      workbook.Version = ExcelVersion.Excel2013;

      var exportFilename = "Filled-StartupList.xlsx";

      var XLSFullPath = Path.Combine(AppContext.BaseDirectory, exportFilename);
      workbook.SaveAs(XLSFullPath);

      //Saving the workbook to disk. This spreadsheet is the result of opening and modifying
      //an existing spreadsheet and then saving the result to a new workbook.
      var PDFFilename = "Filled-StartupList.pdf";
      var PDFFullPath = Path.Combine(AppContext.BaseDirectory, PDFFilename);

      var converter = new ExcelToPdfConverter(workbook);
      //Intialize the PDFDocument
      var pdfDoc = new PdfDocument();
      //Intialize the ExcelToPdfconverterSettings
      var settings = new ExcelToPdfConverterSettings();
      //Assign the PDFDocument to the TemplateDocument property of ExcelToPdfConverterSettings
      settings.TemplateDocument = pdfDoc;
      settings.EmbedFonts = true;
      //Convert Excel Document into PDF document
      pdfDoc = converter.Convert(settings);

      //Save the pdf file
      pdfDoc.Save(PDFFullPath);

      string outputPath = PDFFullPath;

      //Save the pdf file
      //string outputPath = GetFullOutputPath("Output.pdf");
      //pdfDoc.Save(outputPath);
      workbook.Close();
      pdfDoc.Close();
      excelEngine.Dispose();
      pdfDoc.Dispose();
      #endregion


      #region View the Workbook
      //Message box confirmation to view the created document.
      if (MessageBox.Show("Do you want to view the PDF?", "PDF has been created",
      MessageBoxButtons.YesNo, MessageBoxIcon.Information)
      == DialogResult.Yes)
      {
        try
        {
          //Launching the Excel file using the default Application.[MS Excel Or Free ExcelViewer]
          System.Diagnostics.Process.Start(outputPath);

          //Exit
          this.Close();
        }
        catch (Win32Exception ex)
        {
          MessageBox.Show("PDF viewer is not installed in this system");
          Console.WriteLine(ex.ToString());
        }
      }
      else
        this.Close();
      #endregion
    }
    #endregion

    #region HelperMethods
    private string GetFullTemplatePath(string inputFile)
    {
      return string.Format(DEFAULTPATH, inputFile);
    }

    private string GetFullOutputPath(string outputFile)
    {
      return string.Format(OUTPUTPATH, outputFile);
    }

    #endregion

    #region Windows Form Designer generated code
    /// <summary>
    /// Required method for Designer support - do not modify
    /// the contents of this method with the code editor.
    /// </summary>
    private void InitializeComponent()
    {
      System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(CreateSpreadsheet));
      this.btnCreate = new System.Windows.Forms.Button();
      this.label2 = new System.Windows.Forms.Label();
      this.pictureBox3 = new System.Windows.Forms.PictureBox();
      ((System.ComponentModel.ISupportInitialize)(this.pictureBox3)).BeginInit();
      this.SuspendLayout();
      // 
      // btnCreate
      // 
      this.btnCreate.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
      this.btnCreate.BackColor = System.Drawing.Color.Transparent;
      this.btnCreate.Image = ((System.Drawing.Image)(resources.GetObject("btnCreate.Image")));
      this.btnCreate.ImageAlign = System.Drawing.ContentAlignment.MiddleRight;
      this.btnCreate.Location = new System.Drawing.Point(252, 109);
      this.btnCreate.Name = "btnCreate";
      this.btnCreate.Size = new System.Drawing.Size(213, 48);
      this.btnCreate.TabIndex = 0;
      this.btnCreate.Text = "Generate PDF";
      this.btnCreate.UseVisualStyleBackColor = false;
      this.btnCreate.Click += new System.EventHandler(this.btnCreate_Click);
      // 
      // label2
      // 
      this.label2.Font = new System.Drawing.Font("Verdana", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(161)));
      this.label2.ForeColor = System.Drawing.SystemColors.ControlText;
      this.label2.Location = new System.Drawing.Point(0, 160);
      this.label2.Name = "label2";
      this.label2.Size = new System.Drawing.Size(852, 89);
      this.label2.TabIndex = 64;
      this.label2.Text = "Click the button to view an PDF generated by Essential XlsIO.";
      this.label2.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
      // 
      // pictureBox3
      // 
      this.pictureBox3.Image = ((System.Drawing.Image)(resources.GetObject("pictureBox3.Image")));
      this.pictureBox3.Location = new System.Drawing.Point(0, 0);
      this.pictureBox3.Name = "pictureBox3";
      this.pictureBox3.Size = new System.Drawing.Size(639, 71);
      this.pictureBox3.SizeMode = System.Windows.Forms.PictureBoxSizeMode.AutoSize;
      this.pictureBox3.TabIndex = 75;
      this.pictureBox3.TabStop = false;
      // 
      // CreateSpreadsheet
      // 
      this.AutoScaleBaseSize = new System.Drawing.Size(10, 24);
      this.BackColor = System.Drawing.Color.White;
      this.ClientSize = new System.Drawing.Size(783, 282);
      this.Controls.Add(this.label2);
      this.Controls.Add(this.btnCreate);
      this.Controls.Add(this.pictureBox3);
      this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle;
      this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
      this.MaximizeBox = false;
      this.Name = "CreateSpreadsheet";
      this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
      this.Text = "Create Spreadsheet";
      ((System.ComponentModel.ISupportInitialize)(this.pictureBox3)).EndInit();
      this.ResumeLayout(false);
      this.PerformLayout();

    }
    #endregion

    #region Dispose methods
    /// <summary>
    /// Clean up any resources being used.
    /// </summary>
    protected override void Dispose(bool disposing)
    {
      if (disposing)
      {
        if (components != null)
        {
          components.Dispose();
        }
      }
      base.Dispose(disposing);
    }



    /// <summary>
    /// The main entry point for the application.
    /// </summary>
    [STAThread]
    static void Main()
    {
      Application.EnableVisualStyles();
      Application.Run(new CreateSpreadsheet());
    }
    #endregion





  }
}